@@ -628,10 +628,7 @@ static void setLineType(cairo_t *cr, const pGEcontext gc)
   cairo_line_join_t join = CAIRO_LINE_JOIN_ROUND;
   static double dashes[8];
   gint i;
-	
-  if(gc->lwd < 1)
-    gc->lwd=1;
-	
+  
   cairo_set_line_width(cr, gc->lwd);
 	
   switch(gc->lend) {
@@ -672,11 +669,11 @@ static void setLineType(cairo_t *cr, const pGEcontext gc)
 
 static void drawShape(cairo_t *cr, const pGEcontext gc)
 {
-  if (gc->fill != NA_INTEGER) {
+  if (R_ALPHA(gc->fill) > 0) {
     setColor(cr, gc->fill);
     cairo_fill_preserve(cr);
   }
-  if (gc->col != NA_INTEGER) {
+  if (R_ALPHA(gc->col) > 0 && gc->lty != -1) {
     setColor(cr, gc->col);
     setLineType(cr, gc);
     cairo_stroke(cr);
